@@ -128,9 +128,9 @@ protected:
     bool visit(UsingNamespaceDirective *) override { return false; }
     bool visit(UsingDeclaration *) override { return false; }
     bool visit(NamespaceAlias *) override { return false; }
-    bool visit(Declaration *) override { return false; }
     bool visit(Argument *) override { return false; }
     bool visit(TypenameArgument *) override { return false; }
+    bool visit(TemplateTypeArgument *) override { return false; }
     bool visit(BaseClass *) override { return false; }
     bool visit(ForwardClassDeclaration *) override { return false; }
 
@@ -158,6 +158,13 @@ protected:
         return true;
     }
 
+    bool visit(Declaration *decl) override
+    {
+        if (const auto func = decl->type().type()->asFunctionType())
+            return process(func);
+        return false;
+    }
+
     // Objective-C
     bool visit(ObjCBaseClass *) override { return false; }
     bool visit(ObjCBaseProtocol *) override { return false; }
@@ -324,7 +331,7 @@ void Document::addMacroUse(const Macro &macro,
                            int bytesOffset, int bytesLength,
                            int utf16charsOffset, int utf16charLength,
                            int beginLine,
-                           const QVector<MacroArgumentReference> &actuals)
+                           const QList<MacroArgumentReference> &actuals)
 {
     MacroUse use(macro,
                  bytesOffset, bytesOffset + bytesLength,
@@ -350,6 +357,15 @@ void Document::addUndefinedMacroUse(const QByteArray &name,
     _undefinedMacroUses.append(use);
 }
 
+int Document::pragmaOnceLine() const
+{
+    for (const Pragma &p : _pragmas) {
+        if (p.tokens.size() == 1 && p.tokens.first() == "once")
+            return p.line;
+    }
+    return -1;
+}
+
 /*!
     \class Document::MacroUse
     \brief The MacroUse class represents the usage of a macro in a
@@ -577,10 +593,10 @@ bool Document::isParsed() const
 
 bool Document::parse(ParseMode mode)
 {
-    TranslationUnit::ParseMode m = TranslationUnit::ParseTranlationUnit;
+    TranslationUnit::ParseMode m = TranslationUnit::ParseTranslationUnit;
     switch (mode) {
-    case ParseTranlationUnit:
-        m = TranslationUnit::ParseTranlationUnit;
+    case ParseTranslationUnit:
+        m = TranslationUnit::ParseTranslationUnit;
         break;
 
     case ParseDeclaration:
@@ -719,6 +735,7 @@ static QList<Macro> macrosDefinedUntilLine(const QList<Macro> &macros, int line)
 
 Document::Ptr Snapshot::preprocessedDocument(const QByteArray &source,
                                              const FilePath &filePath,
+                                             bool expandFunctionLikeMacros,
                                              int withDefinedMacrosFromDocumentUntilLine) const
 {
     Document::Ptr newDoc = Document::create(filePath);
@@ -735,7 +752,7 @@ Document::Ptr Snapshot::preprocessedDocument(const QByteArray &source,
         }
     }
 
-    FastPreprocessor pp(*this);
+    FastPreprocessor pp(*this, expandFunctionLikeMacros);
     const bool mergeDefinedMacrosOfDocument = !newDoc->_definedMacros.isEmpty();
     const QByteArray preprocessedCode = pp.run(newDoc, source, mergeDefinedMacrosOfDocument);
     newDoc->setUtf8Source(preprocessedCode);
